.. _api.derivation_rule:

================
Derivation rules
================
.. currentmodule:: grammatica.grammar

Constructor
-----------
.. autosummary::
   :toctree: api/

   DerivationRule

Attributes
----------

.. autosummary::
   :toctree: api/

   DerivationRule.symbol
   DerivationRule.value

Rendering
---------

.. autosummary::
   :toctree: api/

   DerivationRule.render
   DerivationRule.as_string

Simplification
--------------

.. autosummary::
   :toctree: api/

   DerivationRule.simplify

Utility
-----------------

.. autosummary::
   :toctree: api/

   DerivationRule.copy
   DerivationRule.equals

Metadata
--------

.. warning:: ``DerivationRule.attrs_dict`` is considered experimental and may change without warning.

.. autosummary::
   :toctree: api/

   DerivationRule.attrs_dict
